@@ -1,7 +1,5 @@
 package NpsSDK::SoapClient;
 
-
-
 use warnings; 
 use strict;
 
@@ -11,8 +9,8 @@ use NpsSDK::Constants;
 use NpsSDK::Errors;
 
 use Data::Structure::Util qw( unbless ); 
-
-our $VERSION = '1.4'; # VERSION
+use Log::Log4perl;
+our $VERSION = '1.5'; # VERSION
 
 my $connection; 
 my $response; 
@@ -21,10 +19,10 @@ my $error;
 sub _setup {
     my $self = shift;
     if (defined $NpsSDK::Configuration::logger) { 
-        NpsSDK::LogException->error if ($NpsSDK::Configuration::log_level eq $NpsSDK::Constants::DEBUG and 
+        NpsSDK::LogException->error if ($NpsSDK::Configuration::log_level eq $Log::Log4perl::DEBUG and 
                                 $NpsSDK::Configuration::environment eq $NpsSDK::Constants::PRODUCTION_ENV); 
 
-    if ($NpsSDK::Configuration::log_level > $NpsSDK::Constants::DEBUG){
+    if ($NpsSDK::Configuration::log_level > $Log::Log4perl::DEBUG){
         eval {  require SOAP::Lite;
                 SOAP::Lite->import(+trace => [ transport => sub {
                 my ($http_object) = @_;
